<?php

/**
 * Custom SolrBaseQuery class for Apachesolr Views.
 *
 * Needed to set proper base path for facets.
 */
class ApachesolrViewsSolrBaseQuery extends SolrBaseQuery {

  /**
   * @param $name
   *   The search name, used for finding the correct blocks and other config.
   *   Typically "apachesolr".
   *
   * @param $solr
   *   An instantiated DrupalApacheSolrService Object.
   *   Can be instantiated from apachesolr_get_solr().
   *
   * @param $params
   *   Array of params to initialize the object (typically 'q' and 'fq').
   *
   * @param $sortstring
   *   Visible string telling solr how to sort - added to GET query params.
   *
   * @param $base_path
   *   The search base path (without the keywords) for this query, without trailing slash.
   *
   * @param $context
   *   The context values.
   */
  function __construct($name, $solr, array $params = array(), $sortstring = '', $base_path = '', $context = array()) {
    if (empty($context['page_id'])) {
      // TODO
      // Does apachesolr_views only work with the default search page's settings?
      // Seems like a missing feature. The search page (and it's settings)
      // should be selectable in the view's settings.
      $context['page_id'] = apachesolr_search_default_search_page();
    }
    parent::__construct($name, $solr, $params, $sortstring, $base_path, $context);
  }

  public function getPath($new_keywords = NULL) {
    if (isset($new_keywords)) {
      return $this->base_path . '/' . $new_keywords;
    }
    return $this->base_path;
  }
}
